@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2022, 2024 Arm Limited.
+ * Copyright (c) 2017-2022, 2024-2025 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -24,8 +24,13 @@
 #ifndef ACL_ARM_COMPUTE_CORE_CPP_CPPTYPES_H
 #define ACL_ARM_COMPUTE_CORE_CPP_CPPTYPES_H
 
+/** @file
+ * @publicapi
+ */
+
 #include "arm_compute/core/Error.h"
 
+#include <cstdint>
 #include <memory>
 
 namespace arm_compute
@@ -180,7 +185,12 @@ public:
      *
      * @return Vector length if sme2 is enabled, otherwise returns 0.
      */
-    uint64_t get_sme2_vector_length() const;
+    uint64_t get_sme2_vector_length_in_bytes() const;
+    /** Return the vector length in bits for sme2
+     *
+     * @return Vector length if sme2 is enabled, otherwise returns 0.
+     */
+    uint64_t get_sme2_vector_length_in_bits() const;
 
 private:
     struct Impl;
