@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2023 Arm Limited.
+ * Copyright (c) 2016-2025 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,8 +21,12 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_ITENSORINFO_H
-#define ARM_COMPUTE_ITENSORINFO_H
+#ifndef ACL_ARM_COMPUTE_CORE_ITENSORINFO_H
+#define ACL_ARM_COMPUTE_CORE_ITENSORINFO_H
+
+/** @file
+ * @publicapi
+ */
 
 #include "arm_compute/core/Coordinates.h"
 #include "arm_compute/core/Strides.h"
@@ -32,7 +36,9 @@
 
 #include "support/ICloneable.h"
 
+#include <array>
 #include <cstddef>
+#include <cstdint>
 
 namespace arm_compute
 {
@@ -44,7 +50,7 @@ class QuantizationInfo;
 class ITensorInfo : public misc::ICloneable<ITensorInfo>
 {
 public:
-    using TensorDimsState = std::vector<int>;
+    using TensorDimsState = std::array<int, arm_compute::MAX_DIMS>;
     /** An id that uniquely identifies an ITensorInfo within some domain (e.g. a workload)
      */
     using Id = int32_t;
@@ -255,6 +261,13 @@ public:
      * @return True if the tensor size can be changed.
      */
     virtual bool is_resizable() const = 0;
+    /** Set the tensor as dynamic/static
+     *
+     * @param[in] dynamic True if tensor is dynamic
+     *
+     * @return Reference to this ITensorInfo object
+     */
+    virtual ITensorInfo &set_dynamic(bool dynamic) = 0;
     /** Flag indicating whether the shape of the tensor is dynamic, meaning that it can change on kernel/function execution.
      *
      * @return True if its dynamic else false
@@ -279,6 +292,13 @@ public:
      * @return Reference to this ITensorInfo object
      */
     virtual ITensorInfo &set_are_values_constant(bool are_values_constant) = 0;
+    /** Set the offset from the beginning of the memory allocation to the first element of the tensor.
+     *
+     * @param[in] offset Offset in bytes to first element in tensor.
+     *
+     * @return Reference to this ITensorInfo object
+     */
+    virtual ITensorInfo &set_offset_first_element_in_bytes(const size_t offset) = 0;
     /** Valid region of the tensor. All elements in the valid region have defined values, i.e. are not undefined.
      *
      * @return The valid region.
@@ -364,4 +384,4 @@ private:
     static constexpr int32_t _static_dimension  = 0;
 };
 } // namespace arm_compute
-#endif /*ARM_COMPUTE_TENSORINFO_H */
+#endif // ACL_ARM_COMPUTE_CORE_ITENSORINFO_H
