@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2023 Arm Limited.
+ * Copyright (c) 2017-2025 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,8 +21,12 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_SUBTENSORINFO_H
-#define ARM_COMPUTE_SUBTENSORINFO_H
+#ifndef ACL_ARM_COMPUTE_CORE_SUBTENSORINFO_H
+#define ACL_ARM_COMPUTE_CORE_SUBTENSORINFO_H
+
+/** @file
+ * @publicapi
+ */
 
 #include "arm_compute/core/Coordinates.h"
 #include "arm_compute/core/Helpers.h"
@@ -196,7 +200,8 @@ public:
         ARM_COMPUTE_ERROR_ON(_parent == nullptr);
         return _parent->is_resizable();
     }
-    bool is_dynamic() const override
+    ITensorInfo &set_dynamic(bool dynamic) override;
+    bool         is_dynamic() const override
     {
         ARM_COMPUTE_ERROR_ON(_parent == nullptr);
         return _parent->is_dynamic();
@@ -253,6 +258,12 @@ public:
         _parent->set_id(id);
         return *this;
     }
+    ITensorInfo &set_offset_first_element_in_bytes(const size_t offset) override
+    {
+        ARM_COMPUTE_ERROR_ON(_parent == nullptr);
+        _parent->set_offset_first_element_in_bytes(offset);
+        return *this;
+    }
 
 private:
     ITensorInfo    *_parent;
@@ -264,4 +275,4 @@ private:
     bool            _lock_paddings;
 };
 } // namespace arm_compute
-#endif /*ARM_COMPUTE_SUBTENSORINFO_H */
+#endif // ACL_ARM_COMPUTE_CORE_SUBTENSORINFO_H
