@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2024 Arm Limited.
+ * Copyright (c) 2016-2025 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -24,6 +24,10 @@
 #ifndef ACL_ARM_COMPUTE_FUNCTION_INFO_ACTIVATIONLAYERINFO_H
 #define ACL_ARM_COMPUTE_FUNCTION_INFO_ACTIVATIONLAYERINFO_H
 
+/** @file
+ * @publicapi
+ */
+
 #include "arm_compute/core/CoreTypes.h"
 #include "arm_compute/core/Error.h"
 #include "arm_compute/core/QuantizationInfo.h"
@@ -65,6 +69,7 @@ public:
 
     /** Lookup table  */
 #ifdef __aarch64__
+    // TODO (COMPMID-7511): delegate to LUTManager
     using LookupTable256   = std::array<qasymm8_t, 256>;
     using LookupTable65536 = std::array<float16_t, 65536>;
 #endif // __aarch64__
@@ -134,6 +139,10 @@ public:
     {
         return this->_act == l._act && this->_a == l._a && this->_b == l._b && this->_enabled == l._enabled;
     }
+    bool operator!=(const ActivationLayerInfo &l) const
+    {
+        return !(*this == l);
+    }
 
 private:
     ActivationFunction _act     = {ActivationLayerInfo::ActivationFunction::IDENTITY};
